pub struct PreimageKey {
pub key_type: KeyType,
pub x: [u8; 31],
}Fields
key_type: KeyTypex: [u8; 31]Implementations
Sourceimpl PreimageKey
impl PreimageKey
pub fn new(key_type: KeyType, x: [u8; 31]) -> Self
Sourcepub fn new_keccak(hash: [u8; 32]) -> Self
pub fn new_keccak(hash: [u8; 32]) -> Self
produce a key from 32 byte of a Keccak hash. The first byte is discarded and replaced by the type byte
Sourcepub fn new_sha256(hash: [u8; 32]) -> Self
pub fn new_sha256(hash: [u8; 32]) -> Self
produce a key from 32 byte of a Sha256 hash. The first byte is discarded and replaced by the type byte